@@ -542,29 +542,32 @@ def stats_helper(path: str = None):
                     return
                 
                 # Get stats
-                stats_query = """
-                MATCH (r:Repository {path: $path})-[:CONTAINS]->(f:File)
-                WITH r, count(f) as file_count, f
-                OPTIONAL MATCH (f)-[:CONTAINS]->(func:Function)
-                OPTIONAL MATCH (f)-[:CONTAINS]->(cls:Class)
-                OPTIONAL MATCH (f)-[:IMPORTS]->(m:Module)
-                RETURN 
-                    file_count,
-                    count(DISTINCT func) as function_count,
-                    count(DISTINCT cls) as class_count,
-                    count(DISTINCT m) as module_count
-                """
-                result = session.run(stats_query, path=str(path_obj))
-                record = result.single()
+                # Get stats using separate queries to handle depth and avoid Cartesian products
+                # 1. Files
+                file_query = "MATCH (r:Repository {path: $path})-[:CONTAINS*]->(f:File) RETURN count(f) as c"
+                file_count = session.run(file_query, path=str(path_obj)).single()["c"]
                 
+                # 2. Functions (including methods in classes)
+                func_query = "MATCH (r:Repository {path: $path})-[:CONTAINS*]->(func:Function) RETURN count(func) as c"
+                func_count = session.run(func_query, path=str(path_obj)).single()["c"]
+                
+                # 3. Classes
+                class_query = "MATCH (r:Repository {path: $path})-[:CONTAINS*]->(c:Class) RETURN count(c) as c"
+                class_count = session.run(class_query, path=str(path_obj)).single()["c"]
+                
+                # 4. Modules (imported) - Note: Module nodes are outside the repo structure usually, connected via IMPORTS
+                # We need to traverse from files to modules
+                module_query = "MATCH (r:Repository {path: $path})-[:CONTAINS*]->(f:File)-[:IMPORTS]->(m:Module) RETURN count(DISTINCT m) as c"
+                module_count = session.run(module_query, path=str(path_obj)).single()["c"]
+
                 table = Table(show_header=True, header_style="bold magenta")
                 table.add_column("Metric", style="cyan")
                 table.add_column("Count", style="green", justify="right")
                 
-                table.add_row("Files", str(record["file_count"] if record else 0))
-                table.add_row("Functions", str(record["function_count"] if record else 0))
-                table.add_row("Classes", str(record["class_count"] if record else 0))
-                table.add_row("Imported Modules", str(record["module_count"] if record else 0))
+                table.add_row("Files", str(file_count))
+                table.add_row("Functions", str(func_count))
+                table.add_row("Classes", str(class_count))
+                table.add_row("Imported Modules", str(module_count))
                 
                 console.print(table)
         else:
@@ -572,34 +575,24 @@ def stats_helper(path: str = None):
             console.print("[cyan]📊 Overall Database Statistics[/cyan]\n")
             
             with db_manager.get_driver().session() as session:
-                # Get overall counts using separate queries to avoid empty results
-                # when some node types don't exist
-                stats_query = """
-                MATCH (r:Repository)
-                OPTIONAL MATCH (f:File)
-                OPTIONAL MATCH (func:Function)
-                OPTIONAL MATCH (cls:Class)
-                OPTIONAL MATCH (m:Module)
-                RETURN 
-                    count(DISTINCT r) as repo_count,
-                    count(DISTINCT f) as file_count,
-                    count(DISTINCT func) as function_count,
-                    count(DISTINCT cls) as class_count,
-                    count(DISTINCT m) as module_count
-                """
-                result = session.run(stats_query)
-                record = result.single()
+                # Get overall counts using separate O(1) queries
+                repo_count = session.run("MATCH (r:Repository) RETURN count(r) as c").single()["c"]
                 
-                if record and record["repo_count"] > 0:
+                if repo_count > 0:
+                    file_count = session.run("MATCH (f:File) RETURN count(f) as c").single()["c"]
+                    func_count = session.run("MATCH (f:Function) RETURN count(f) as c").single()["c"]
+                    class_count = session.run("MATCH (c:Class) RETURN count(c) as c").single()["c"]
+                    module_count = session.run("MATCH (m:Module) RETURN count(m) as c").single()["c"]
+                    
                     table = Table(show_header=True, header_style="bold magenta")
                     table.add_column("Metric", style="cyan")
                     table.add_column("Count", style="green", justify="right")
                     
-                    table.add_row("Repositories", str(record["repo_count"]))
-                    table.add_row("Files", str(record["file_count"]))
-                    table.add_row("Functions", str(record["function_count"]))
-                    table.add_row("Classes", str(record["class_count"]))
-                    table.add_row("Modules", str(record["module_count"]))
+                    table.add_row("Repositories", str(repo_count))
+                    table.add_row("Files", str(file_count))
+                    table.add_row("Functions", str(func_count))
+                    table.add_row("Classes", str(class_count))
+                    table.add_row("Modules", str(module_count))
                     
                     console.print(table)
                 else:
