@@ -1,8 +1,8 @@
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
-import logging
 import re
-import ast  # Not strictly needed for JS, but kept for consistency if AST manipulation is added
+from codegraphcontext.utils.debug_log import debug_log, info_logger, error_logger, warning_logger
+from codegraphcontext.utils.tree_sitter_manager import execute_query
 
 # --- Helpers to classify JS methods ---
 _GETTER_RE = re.compile(r"^\s*(?:static\s+)?get\b")
@@ -35,8 +35,6 @@ def _classify_method_kind(header: str) -> Optional[str]:
     return None
 
 
-logger = logging.getLogger(__name__)
-
 JS_QUERIES = {
     "functions": """
         (function_declaration 
@@ -46,7 +44,7 @@ JS_QUERIES = {
         
         (variable_declarator 
             name: (identifier) @name 
-            value: (function 
+            value: (function_expression 
                 parameters: (formal_parameters) @params
             ) @function_node
         )
@@ -74,7 +72,7 @@ JS_QUERIES = {
             left: (member_expression 
                 property: (property_identifier) @name
             )
-            right: (function
+            right: (function_expression
                 parameters: (formal_parameters) @params
             ) @function_node
         )
@@ -101,6 +99,8 @@ JS_QUERIES = {
     "calls": """
         (call_expression function: (identifier) @name)
         (call_expression function: (member_expression property: (property_identifier) @name))
+        (new_expression constructor: (identifier) @name)
+        (new_expression constructor: (member_expression property: (property_identifier) @name))
     """,
     "variables": """
         (variable_declarator name: (identifier) @name)
@@ -120,20 +120,24 @@ class JavascriptTreeSitterParser:
         self.language = generic_parser_wrapper.language
         self.parser = generic_parser_wrapper.parser
 
-        self.queries = {
-            name: self.language.query(query_str)
-            for name, query_str in JS_QUERIES.items()
-        }
-
     def _get_node_text(self, node) -> str:
         return node.text.decode('utf-8')
 
-    def _get_parent_context(self, node, types=('function_declaration', 'class_declaration')):
+    def _get_parent_context(self, node, types=('function_declaration', 'class_declaration', 'function_expression', 'method_definition', 'arrow_function')):
         # JS specific context types
         curr = node.parent
         while curr:
             if curr.type in types:
                 name_node = curr.child_by_field_name('name')
+                if not name_node and curr.type in ('function_expression', 'arrow_function'):
+                    # Try to find name from variable declaration
+                    if curr.parent and curr.parent.type == 'variable_declarator':
+                        name_node = curr.parent.child_by_field_name('name')
+                    elif curr.parent and curr.parent.type == 'assignment_expression':
+                        name_node = curr.parent.child_by_field_name('left')
+                    elif curr.parent and curr.parent.type == 'pair': # property: function
+                        name_node = curr.parent.child_by_field_name('key')
+                
                 return self._get_node_text(name_node) if name_node else None, curr.type, curr.start_point[0] + 1
             curr = curr.parent
         return None, None, None
@@ -162,8 +166,9 @@ class JavascriptTreeSitterParser:
         # This is a placeholder and needs more sophisticated logic
         return None
 
-    def parse(self, file_path: Path, is_dependency: bool = False) -> Dict:
+    def parse(self, file_path: Path, is_dependency: bool = False, index_source: bool = False) -> Dict[str, Any]:
         """Parses a file and returns its structure in a standardized dictionary format."""
+        self.index_source = index_source
         with open(file_path, "r", encoding="utf-8") as f:
             source_code = f.read()
 
@@ -189,17 +194,17 @@ class JavascriptTreeSitterParser:
 
     def _find_functions(self, root_node):
         functions = []
-        query = self.queries['functions']
+        query_str = JS_QUERIES['functions']
 
     # Local helpers so we don't depend on class attrs being present
         def _fn_for_name(name_node):
             current = name_node.parent
             while current:
-                if current.type in ('function_declaration', 'function', 'arrow_function', 'method_definition'):
+                if current.type in ('function_declaration', 'function', 'arrow_function', 'method_definition', 'function_expression'):
                     return current
                 elif current.type in ('variable_declarator', 'assignment_expression'):
                     for child in current.children:
-                        if child.type in ('function', 'arrow_function'):
+                        if child.type in ('function', 'arrow_function', 'function_expression'):
                             return child
                 current = current.parent
             return None
@@ -207,7 +212,7 @@ class JavascriptTreeSitterParser:
         def _fn_for_params(params_node):
             current = params_node.parent
             while current:
-                if current.type in ('function_declaration', 'function', 'arrow_function', 'method_definition'):
+                if current.type in ('function_declaration', 'function', 'arrow_function', 'method_definition', 'function_expression'):
                     return current
                 current = current.parent
             return None
@@ -218,12 +223,12 @@ class JavascriptTreeSitterParser:
         # Collect captures grouped by function node
         captures_by_function = {}
         def _bucket_for(node):
-            fid = id(node)
+            fid = _key(node)
             return captures_by_function.setdefault(fid, {
                 'node': node, 'name': None, 'params': None, 'single_param': None
             })
 
-        for node, capture_name in query.captures(root_node):
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name == 'function_node':
                 _bucket_for(node)
             elif capture_name == 'name':
@@ -278,17 +283,13 @@ class JavascriptTreeSitterParser:
                 "line_number": func_node.start_point[0] + 1,
                 "end_line": func_node.end_point[0] + 1,
                 "args": args,
-                "source": self._get_node_text(func_node),
-                "source_code": self._get_node_text(func_node),
-                "docstring": docstring,
-                "cyclomatic_complexity": self._calculate_complexity(func_node),
-                "context": context,
-                "context_type": context_type,
-                "class_context": class_context,
-                "decorators": [],
                 "lang": self.language_name,
                 "is_dependency": False,
             }
+
+            if self.index_source:
+                func_data["source"] = self._get_node_text(func_node)
+                func_data["docstring"] = docstring
             if js_kind is not None:
                 func_data["type"] = js_kind
 
@@ -359,8 +360,8 @@ class JavascriptTreeSitterParser:
 
     def _find_classes(self, root_node):
         classes = []
-        query = self.queries['classes']
-        for class_node, capture_name in query.captures(root_node):
+        query_str = JS_QUERIES['classes']
+        for class_node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name == 'class':
                 name_node = class_node.child_by_field_name('name')
                 if not name_node: continue
@@ -382,21 +383,24 @@ class JavascriptTreeSitterParser:
                     "line_number": class_node.start_point[0] + 1,
                     "end_line": class_node.end_point[0] + 1,
                     "bases": bases,
-                    "source": self._get_node_text(class_node),
-                    "docstring": self._get_docstring(class_node),
                     "context": None,
                     "decorators": [],
                     "lang": self.language_name,
                     "is_dependency": False,
                 }
+
+                if self.index_source:
+                    class_data["source"] = self._get_node_text(class_node)
+                    class_data["docstring"] = self._get_docstring(class_node)
+
                 classes.append(class_data)
         return classes
 
 
     def _find_imports(self, root_node):
         imports = []
-        query = self.queries['imports']
-        for node, capture_name in query.captures(root_node):
+        query_str = JS_QUERIES['imports']
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name != 'import':
                 continue
 
@@ -458,24 +462,36 @@ class JavascriptTreeSitterParser:
 
     def _find_calls(self, root_node):
         calls = []
-        query = self.queries['calls']
-        for node, capture_name in query.captures(root_node):
+        query_str = JS_QUERIES['calls']
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             # Placeholder for JS call extraction logic
             if capture_name == 'name':
+                # Traverse up to find the call_expression
                 call_node = node.parent
+                while call_node and call_node.type != 'call_expression' and call_node.type != 'program':
+                    call_node = call_node.parent
+                
                 name = self._get_node_text(node)
 
-                # Simplified args extraction for now
+                # Improved args extraction
                 args = []
+                arguments_node = None
+                if call_node and call_node.type in ('call_expression', 'new_expression'):
+                    arguments_node = call_node.child_by_field_name('arguments')
+                
+                if arguments_node:
+                    for arg in arguments_node.children:
+                        if arg.type not in ('(', ')', ','):
+                            args.append(self._get_node_text(arg))
 
                 call_data = {
                     "name": name,
-                    "full_name": self._get_node_text(call_node),  # This might need refinement
+                    "full_name": self._get_node_text(call_node),
                     "line_number": node.start_point[0] + 1,
                     "args": args,
                     "inferred_obj_type": None,
-                    "context": None,  # Placeholder
-                    "class_context": None,  # Placeholder
+                    "context": self._get_parent_context(node),
+                    "class_context": self._get_parent_context(node, types=('class_declaration',))[:2],
                     "lang": self.language_name,
                     "is_dependency": False,
                 }
@@ -485,25 +501,48 @@ class JavascriptTreeSitterParser:
 
     def _find_variables(self, root_node):
         variables = []
-        query = self.queries['variables']
-        for match in query.captures(root_node):
+        query_str = JS_QUERIES['variables']
+        for match in execute_query(self.language, query_str, root_node):
             capture_name = match[1]
             node = match[0]
 
-            # Placeholder for JS variable extraction logic
             if capture_name == 'name':
                 var_node = node.parent
                 name = self._get_node_text(node)
-                value = None  # Placeholder
-                type_text = None  # Placeholder
+                value = None 
+                type_text = None
+
+                # Detect if variable assigned to a function
+                value_node = var_node.child_by_field_name("value") if var_node else None
+
+                if value_node:
+                    value_type = value_node.type
+
+                    # --- Skip variables that are assigned a function ---
+                    if value_type in ("function_expression", "arrow_function"):
+                        continue
+                    
+                    # Some grammars might have async_arrow_function or similar
+                    if "function" in value_type or "arrow" in value_type:
+                        continue
+
+                    # --- Handle various assignment types ---
+                    if value_type == "call_expression":
+                        func_node = value_node.child_by_field_name("function")
+                        value = self._get_node_text(func_node) if func_node else name
+                    else:
+                        value = self._get_node_text(value_node)
+
+                context, context_type, context_line = self._get_parent_context(node)
+                class_context = context if context_type == 'class_declaration' else None
 
                 variable_data = {
                     "name": name,
                     "line_number": node.start_point[0] + 1,
                     "value": value,
                     "type": type_text,
-                    "context": None,  # Placeholder
-                    "class_context": None,  # Placeholder
+                    "context": context,
+                    "class_context": class_context,
                     "lang": self.language_name,
                     "is_dependency": False,
                 }
@@ -517,14 +556,14 @@ def pre_scan_javascript(files: list[Path], parser_wrapper) -> dict:
     query_str = """
         (class_declaration name: (identifier) @name)
         (function_declaration name: (identifier) @name)
-        (variable_declarator name: (identifier) @name value: (function))
+        (variable_declarator name: (identifier) @name value: (function_expression))
         (variable_declarator name: (identifier) @name value: (arrow_function))
         (method_definition name: (property_identifier) @name)
         (assignment_expression
             left: (member_expression 
                 property: (property_identifier) @name
             )
-            right: (function)
+            right: (function_expression)
         )
         (assignment_expression
             left: (member_expression 
@@ -533,18 +572,18 @@ def pre_scan_javascript(files: list[Path], parser_wrapper) -> dict:
             right: (arrow_function)
         )
     """
-    query = parser_wrapper.language.query(query_str)
+    
 
     for file_path in files:
         try:
             with open(file_path, "r", encoding="utf-8") as f:
                 tree = parser_wrapper.parser.parse(bytes(f.read(), "utf8"))
 
-            for capture, _ in query.captures(tree.root_node):
+            for capture, _ in execute_query(parser_wrapper.language, query_str, tree.root_node):
                 name = capture.text.decode('utf-8')
                 if name not in imports_map:
                     imports_map[name] = []
                 imports_map[name].append(str(file_path.resolve()))
         except Exception as e:
-            logger.warning(f"Tree-sitter pre-scan failed for {file_path}: {e}")
+            warning_logger(f"Tree-sitter pre-scan failed for {file_path}: {e}")
     return imports_map
