@@ -45,8 +45,9 @@ class ScalaTreeSitterParser:
         self.language = generic_parser_wrapper.language
         self.parser = generic_parser_wrapper.parser
 
-    def parse(self, file_path: Path, is_dependency: bool = False) -> Dict[str, Any]:
+    def parse(self, file_path: Path, is_dependency: bool = False, index_source: bool = False) -> Dict[str, Any]:
         try:
+            self.index_source = index_source
             with open(file_path, 'r', encoding='utf-8', errors='ignore') as f:
                 source_code = f.read()
 
@@ -189,18 +190,22 @@ class ScalaTreeSitterParser:
                         
                         context_name, context_type, context_line = self._get_parent_context(node)
 
-                        functions.append({
+                        func_data = {
                             "name": func_name,
                             "parameters": parameters,
                             "args": parameters, # 'args' is sometimes used instead of 'parameters'
                             "line_number": start_line,
                             "end_line": end_line,
-                            "source": source_text,
                             "file_path": str(file_path),
                             "lang": self.language_name,
                             "context": context_name,
                             "class_context": context_name if context_type and "class" in str(context_type) or "object" in str(context_type) or "trait" in str(context_type) else None
-                        })
+                        }
+
+                        if self.index_source:
+                            func_data["source"] = source_text
+                        
+                        functions.append(func_data)
                         
                 except Exception as e:
                     error_logger(f"Error parsing function in {file_path}: {e}")
@@ -248,16 +253,20 @@ class ScalaTreeSitterParser:
                         # Note: parsing bases in Scala can be complex (mixins with 'with' keyword).
                         # Using text based regex backup might be safer for now if tree query is hard.
                         
-                        classes.append({
+                        class_data = {
                             "name": class_name,
                             "line_number": start_line,
                             "end_line": end_line,
                             "bases": bases,
-                            "source": source_text,
                             "file_path": str(file_path),
                             "lang": self.language_name,
                             "type": node.type.replace("_definition", "") # class, object, trait
-                        })
+                        }
+
+                        if self.index_source:
+                            class_data["source"] = source_text
+                        
+                        classes.append(class_data)
                         
                 except Exception as e:
                     error_logger(f"Error parsing class in {file_path}: {e}")
